==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/beans/IntrospectionException.hpp <==
#ifndef _COM_SUN_STAR_BEANS_INTROSPECTIONEXCEPTION_HPP_
#define _COM_SUN_STAR_BEANS_INTROSPECTIONEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_BEANS_INTROSPECTIONEXCEPTION_HDL_
#include "com/sun/star/beans/IntrospectionException.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_EXCEPTION_HPP_
#include "com/sun/star/uno/Exception.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace beans {

inline IntrospectionException::IntrospectionException() SAL_THROW( () )
    : ::com::sun::star::uno::Exception()
{ }

inline IntrospectionException::IntrospectionException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_) SAL_THROW( () )
    : ::com::sun::star::uno::Exception(Message_, Context_)
{ }

IntrospectionException::IntrospectionException(IntrospectionException const & the_other): ::com::sun::star::uno::Exception(the_other) {}

IntrospectionException::~IntrospectionException() {}

IntrospectionException & IntrospectionException::operator =(IntrospectionException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::uno::Exception::operator =(the_other);
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::beans::IntrospectionException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.beans.IntrospectionException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_BEANS_INTROSPECTIONEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/beans/IntrospectionException.hpp <==
#ifndef _COM_SUN_STAR_BEANS_INTROSPECTIONEXCEPTION_HPP_
#define _COM_SUN_STAR_BEANS_INTROSPECTIONEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_BEANS_INTROSPECTIONEXCEPTION_HDL_
#include "com/sun/star/beans/IntrospectionException.hdl"
#endif

#ifndef _COM_SUN_STAR_UNO_EXCEPTION_HPP_
#include "com/sun/star/uno/Exception.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif

namespace com { namespace sun { namespace star { namespace beans {

inline IntrospectionException::IntrospectionException() SAL_THROW( () )
    : ::com::sun::star::uno::Exception()
{ }

inline IntrospectionException::IntrospectionException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_) SAL_THROW( () )
    : ::com::sun::star::uno::Exception(Message_, Context_)
{ }

IntrospectionException::IntrospectionException(IntrospectionException const & the_other): ::com::sun::star::uno::Exception(the_other) {}

IntrospectionException::~IntrospectionException() {}

IntrospectionException & IntrospectionException::operator =(IntrospectionException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::uno::Exception::operator =(the_other);
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace beans {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::beans::IntrospectionException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.beans.IntrospectionException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::beans::IntrospectionException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::beans::IntrospectionException >::get();
}

#endif // _COM_SUN_STAR_BEANS_INTROSPECTIONEXCEPTION_HPP_
